@@ -1,20 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.4.3.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
+
+/* Bison interface for Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
-/* Skeleton interface for Bison's Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2009, 2010 Free Software Foundation, Inc.
-   
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -27,84 +26,89 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     ID = 258,
-     SELFOP = 259,
-     DOTS = 260,
-     COLONS = 261,
-     DASHES = 262,
-     INCR = 263,
-     LONGDASH = 264,
-     CONTROLS = 265,
-     TENSION = 266,
-     ATLEAST = 267,
-     CURL = 268,
-     COR = 269,
-     CAND = 270,
-     BAR = 271,
-     AMPERSAND = 272,
-     EQ = 273,
-     NEQ = 274,
-     LT = 275,
-     LE = 276,
-     GT = 277,
-     GE = 278,
-     CARETS = 279,
-     LOGNOT = 280,
-     OPERATOR = 281,
-     LOOSE = 282,
-     ASSIGN = 283,
-     DIRTAG = 284,
-     JOIN_PREC = 285,
-     AND = 286,
-     ELLIPSIS = 287,
-     ACCESS = 288,
-     UNRAVEL = 289,
-     IMPORT = 290,
-     INCLUDE = 291,
-     FROM = 292,
-     QUOTE = 293,
-     STRUCT = 294,
-     TYPEDEF = 295,
-     NEW = 296,
-     IF = 297,
-     ELSE = 298,
-     WHILE = 299,
-     DO = 300,
-     FOR = 301,
-     BREAK = 302,
-     CONTINUE = 303,
-     RETURN_ = 304,
-     THIS = 305,
-     EXPLICIT = 306,
-     GARBAGE = 307,
-     LIT = 308,
-     STRING = 309,
-     PERM = 310,
-     MODIFIER = 311,
-     UNARY = 312,
-     EXP_IN_PARENS_RULE = 313
-   };
+#ifndef YY_YY_CAMP_TAB_H_INCLUDED
+# define YY_YY_CAMP_TAB_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int yydebug;
 #endif
 
+/* Token type.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+  enum yytokentype
+  {
+    ID = 258,
+    SELFOP = 259,
+    DOTS = 260,
+    COLONS = 261,
+    DASHES = 262,
+    INCR = 263,
+    LONGDASH = 264,
+    CONTROLS = 265,
+    TENSION = 266,
+    ATLEAST = 267,
+    CURL = 268,
+    COR = 269,
+    CAND = 270,
+    BAR = 271,
+    AMPERSAND = 272,
+    EQ = 273,
+    NEQ = 274,
+    LT = 275,
+    LE = 276,
+    GT = 277,
+    GE = 278,
+    CARETS = 279,
+    OPERATOR = 280,
+    LOOSE = 281,
+    ASSIGN = 282,
+    DIRTAG = 283,
+    JOIN_PREC = 284,
+    AND = 285,
+    ELLIPSIS = 286,
+    ACCESS = 287,
+    UNRAVEL = 288,
+    IMPORT = 289,
+    INCLUDE = 290,
+    FROM = 291,
+    QUOTE = 292,
+    STRUCT = 293,
+    TYPEDEF = 294,
+    NEW = 295,
+    IF = 296,
+    ELSE = 297,
+    WHILE = 298,
+    DO = 299,
+    FOR = 300,
+    BREAK = 301,
+    CONTINUE = 302,
+    RETURN_ = 303,
+    THIS = 304,
+    EXPLICIT = 305,
+    GARBAGE = 306,
+    LIT = 307,
+    STRING = 308,
+    PERM = 309,
+    MODIFIER = 310,
+    UNARY = 311,
+    EXP_IN_PARENS_RULE = 312
+  };
+#endif
 
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
-{
 
-/* Line 1685 of yacc.c  */
-#line 60 "camp.y"
+union YYSTYPE
+{
+#line 60 "camp.y" /* yacc.c:1909  */
 
   position pos;
   bool boo;
@@ -151,16 +155,17 @@ typedef union YYSTYPE
   absyntax::formal *fl;
   absyntax::formals *fls;
 
+#line 159 "camp.tab.h" /* yacc.c:1909  */
+};
 
-
-/* Line 1685 of yacc.c  */
-#line 158 "camp.tab.h"
-} YYSTYPE;
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
+int yyparse (void);
 
+#endif /* !YY_YY_CAMP_TAB_H_INCLUDED  */
